| Title: | Tools for the OeNB Data Web Service |
| Version: | 0.1.0 |
| Date: | 2026-09-18 |
| Description: | Tools to access data from the data web service of the Oesterreichische Nationalbank (OeNB), https://www.oenb.at/en/Statistics/User-Defined-Tables/webservice.html. |
| License: | GPL-2 | GPL-3 [expanded from: GPL (≥ 2)] |
| Depends: | R (≥ 4.1.0) |
| Imports: | dplyr, utils, XML |
| Encoding: | UTF-8 |
| URL: | https://github.com/franzmohr/oenb |
| BugReports: | https://github.com/franzmohr/oenb/issues |
| Suggests: | curl, knitr, rmarkdown, testthat (≥ 3.2.0) |
| VignetteBuilder: | knitr |
| Config/testthat/edition: | 3 |
| Config/roxygen2/version: | 8.1.0 |
| NeedsCompilation: | no |
| Packaged: | 2026-09-18 18:53:39 UTC; mo_fr |
| Author: | Franz X. Mohr |
| Maintainer: | Franz X. Mohr <franz.x.mohr@outlook.com> |
| Repository: | CRAN |
| Date/Publication: | 2026-09-18 19:10:02 UTC |
Get Attributes
Description
Get potential attributes of individual series from the OeNB's data web service.
Usage
oenb_attributes(id, pos, lang = "EN")
Arguments
id |
character specifying the ID of the dataset of interest.
See |
pos |
character specifying the position ID of the indicator of interest.
See |
lang |
Preferred language of the output. Possible values are "DE" for German and "EN" for English (default). |
Value
A data frame containing potential attributes of a series.
NULL is returned if the web service is not available.
Examples
series_attr <- oenb_attributes(id = "11", pos = "VDBFKBSC217000")
series_attr
Download OeNB Data
Description
Download data sets from the OeNB's data web service https://www.oenb.at/en/Statistics/User-Defined-Tables/webservice.html.
Usage
oenb_data(
id,
pos,
freq = NULL,
attr = NULL,
starttime = NULL,
endtime = NULL,
lang = "EN"
)
Arguments
id |
character specifying the ID of the dataset of interest.
See |
pos |
character vector specifying the position IDs of the indicators of interest.
See |
freq |
Frequency of the data. Where available, possible values are
|
attr |
A named vector of further attributes.
See |
starttime |
character specifying the start of the series. See 'Details'. |
endtime |
character specifying the end of the series. See 'Details'. |
lang |
Preferred language of the output. Possible values are "DE" for German and "EN" for English (default). |
Details
The arguments 'starttime' and 'endtime' can have the format 'YYYY-MM-DD' or 'YYYYMMDD' for daily data, 'YYYY-MM' or 'YYYYMM' for monthly data, and 'YYYY' for annual data. For semiannual data 'YYYY-06' refers to the first half of year 'YYYY' and 'YYYY-12' to the second. Similarly, for quarterly data 'YYYY-03', 'YYYY-06', 'YYYY-09' and 'YYYY-12' refer to the first, second, third and forth quarter of year 'YYYY', respectively.
Value
A data frame. NULL is returned if the query does not return any
data or if the web service is not available.
Examples
series <- oenb_data(id = "11", pos = "VDBFKBSC217000", freq = "M", attr = c("dval1" = "AT"),
starttime = "2019-11", endtime = "2019-12")
series
Content of OeNB Data Sets
Description
Downloads a description of the contents of a specific dataset from the OeNB's data web service.
Usage
oenb_dataset(id, lang = "EN")
Arguments
id |
character specifying the ID of the dataset of interest.
See |
lang |
Preferred language of the output. Possible values are "DE" for German and "EN" for English (default). |
Value
A data frame containing the IDs and names of available indicators within a dataset.
NULL is returned if the web service is not available.
Examples
content <- oenb_dataset(id = "11")
content
Get Frequency
Description
Get available frequencies and periods of individual series from the OeNB's data web service.
Usage
oenb_frequency(id, pos, lang = "EN")
Arguments
id |
character specifying the ID of the dataset of interest.
See |
pos |
character specifying the position ID of the indicator of interest.
See |
lang |
Preferred language of the output. Possible values are "DE" for German and "EN" for English (default). |
Value
A data frame containing available frequencies and periods of a series.
NULL is returned if the web service is not available.
Examples
series_freq <- oenb_frequency(id = "11", pos = "VDBFKBSC217000")
series_freq
Get Metadata
Description
Get metadata on individual series from the OeNB's data web service.
Usage
oenb_metadata(id, pos, lang = "EN")
Arguments
id |
character specifying the ID of the dataset of interest.
See |
pos |
character specifying the position ID of the indicator of interest.
See |
lang |
Preferred language of the output. Possible values are "DE" for German and "EN" for English (default). |
Value
A data frame containing metadata on an indicator.
NULL is returned if the web service is not available.
Examples
meta <- oenb_metadata(id = "11", pos = "VDBFKBSC217000")
meta
Table of Contents
Description
Downloads the table of contents of the OeNB's statistical data web service.
Usage
oenb_toc(lang = "EN")
Arguments
lang |
Preferred language of the output. Possible values are "DE" for German and "EN" for English (default). |
Value
A data frame containing the IDs and titles of available datasets.
NULL is returned if the web service is not available.
Examples
toc <- oenb_toc()
toc